"use strict";

var _recompose = require("recompose");

var _asyncReductions = require("./async-reductions");

test('setAsyncTrueReduction', function () {
  expect((0, _asyncReductions.setAsyncTrueReduction)('a')({})).toEqual({
    a: true
  });
  expect((0, _recompose.compose)((0, _asyncReductions.setAsyncTrueReduction)('a'))({})).toEqual({
    a: true
  });
});
test('setAsyncPageTrueReduction', function () {
  expect((0, _asyncReductions.setAsyncPageTrueReduction)()({})).toEqual({
    page: true
  });
  expect((0, _recompose.compose)((0, _asyncReductions.setAsyncPageTrueReduction)())({})).toEqual({
    page: true
  });
});
test('setAsyncTrueReductionFromAsyncKeyProp', function () {
  expect((0, _asyncReductions.setAsyncTrueReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: true
  });
  expect((0, _recompose.compose)((0, _asyncReductions.setAsyncTrueReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: true
  });
});
test('setAsyncRequestReduction', function () {
  expect((0, _asyncReductions.setAsyncRequestReduction)('a')({})).toEqual({
    a: _asyncReductions.REQUEST
  });
  expect((0, _recompose.compose)((0, _asyncReductions.setAsyncRequestReduction)('a'))({})).toEqual({
    a: _asyncReductions.REQUEST
  });
});
test('setAsyncRequestReductionFromAsyncKeyProp', function () {
  expect((0, _asyncReductions.setAsyncRequestReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: _asyncReductions.REQUEST
  });
  expect((0, _recompose.compose)((0, _asyncReductions.setAsyncRequestReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: _asyncReductions.REQUEST
  });
});
test('setAsyncSuccessReduction', function () {
  expect((0, _asyncReductions.setAsyncSuccessReduction)('a')({})).toEqual({
    a: _asyncReductions.SUCCESS
  });
  expect((0, _recompose.compose)((0, _asyncReductions.setAsyncSuccessReduction)('a'))({})).toEqual({
    a: _asyncReductions.SUCCESS
  });
});
test('setAsyncSuccessReductionFromAsyncKeyProp', function () {
  expect((0, _asyncReductions.setAsyncSuccessReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: _asyncReductions.SUCCESS
  });
  expect((0, _recompose.compose)((0, _asyncReductions.setAsyncSuccessReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: _asyncReductions.SUCCESS
  });
});
test('setAsyncFailureReduction', function () {
  expect((0, _asyncReductions.setAsyncFailureReduction)('a')({})).toEqual({
    a: _asyncReductions.FAILURE
  });
  expect((0, _recompose.compose)((0, _asyncReductions.setAsyncFailureReduction)('a'))({})).toEqual({
    a: _asyncReductions.FAILURE
  });
});
test('setAsyncFailureReductionFromAsyncKeyProp', function () {
  expect((0, _asyncReductions.setAsyncFailureReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: _asyncReductions.FAILURE
  });
  expect((0, _recompose.compose)((0, _asyncReductions.setAsyncFailureReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: _asyncReductions.FAILURE
  });
});
test('setAsyncCustomReductionFromProps', function () {
  expect((0, _asyncReductions.setAsyncCustomReductionFromProps)({
    asyncKey: 'a',
    asyncValue: 'custom'
  })({})).toEqual({
    a: 'custom'
  });
  expect((0, _recompose.compose)((0, _asyncReductions.setAsyncCustomReductionFromProps)({
    asyncKey: 'a',
    asyncValue: 'custom'
  }))({})).toEqual({
    a: 'custom'
  });
});
test('delAsyncReduction', function () {
  var asyncState = {
    foo: 'foo',
    bar: 'bar'
  };
  expect((0, _asyncReductions.delAsyncReduction)('foo')(asyncState)).toEqual({
    bar: 'bar'
  });
  expect((0, _recompose.compose)((0, _asyncReductions.delAsyncReduction)('foo'))(asyncState)).toEqual({
    bar: 'bar'
  });
});
test('delAsyncPageReduction', function () {
  var asyncState = {
    page: 'page',
    bar: 'bar'
  };
  expect((0, _asyncReductions.delAsyncPageReduction)()(asyncState)).toEqual({
    bar: 'bar'
  });
  expect((0, _recompose.compose)((0, _asyncReductions.delAsyncPageReduction)())(asyncState)).toEqual({
    bar: 'bar'
  });
});
test('delAsyncReductionFromAsyncKeyProp', function () {
  var asyncState = {
    foo: 'foo',
    bar: 'bar'
  };
  expect((0, _asyncReductions.delAsyncReductionFromAsyncKeyProp)({
    asyncKey: 'foo'
  })(asyncState)).toEqual({
    bar: 'bar'
  });
  expect((0, _recompose.compose)((0, _asyncReductions.delAsyncReductionFromAsyncKeyProp)({
    asyncKey: 'foo'
  }))(asyncState)).toEqual({
    bar: 'bar'
  });
});
test('clearAsyncExceptPageReduction', function () {
  var asyncState = {
    page: 'page',
    foo: 'foo'
  };
  expect((0, _asyncReductions.clearAsyncExceptPageReduction)()(asyncState)).toEqual({
    page: 'page'
  });
  expect((0, _recompose.compose)((0, _asyncReductions.clearAsyncExceptPageReduction)())(asyncState)).toEqual({
    page: 'page'
  });
});